# site-packages-packer

Pack selected packages from site-packages and output license file.

## Installation

```sh
pip install site-packages-packer
```

## Usage

```sh
pack-site-packages --packages pytest toml --license licences.text --archive package_src.zip --noprint
```
